local LAM = LibStub( 'LibAddonMenu-2.0', true )
	if ( not LAM ) then return end

local SLOT_1 = ActionButton3
local SLOT_2 = ActionButton4
local SLOT_3 = ActionButton5
local SLOT_4 = ActionButton6
local SLOT_5 = ActionButton7

local is_player_in_combat = false;

WM = GetWindowManager()

local defaults = {

	labelPositionY = 45,
	labelPositionX = 10,
	showLabels = false,
	font = "ZoFontWindowTitle",
	fontColor = { 
		r = 1,
		g = 1,
		b = 1,
		a = 1}
}

local function createActionButtonControl(actionButton, id)

	local abc = WM:CreateTopLevelWindow("RechargeCounterClassic_Control" .. id)

	abc:SetDimensions(100, 20)
	abc:SetAnchor(BOTTOM, actionButton, TOP, 0, 0)
	abc:SetScale(1.0)
	abc:SetDrawLayer(1)

	abc:SetAllowBringToTop(true)
	abc:BringWindowToTop()
	
	
	abc.label = WM:CreateControl("RechargeCounterClassic_ControlLabel" .. id, abc, CT_LABEL)
	abc.label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
	abc.label:SetFont(db.font)
	abc.label:SetScale(1)
	abc.label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
	abc.label:SetDrawLayer(1)
	
	ZO_ActionBar1:SetDrawLayer(0.9)
	db.showLabels = false
	
	return abc, abc.label
end

local function createLabels()

	button1, button1_label = createActionButtonControl(SLOT_1,1)
	button2, button2_label = createActionButtonControl(SLOT_2, 2)
	button3, button3_label = createActionButtonControl(SLOT_3, 3)
	button4, button4_label = createActionButtonControl(SLOT_4, 4)
	button5, button5_label = createActionButtonControl(SLOT_5, 5)
	
end

local function setLabels(id, buttonControl, buttonControl_label, abilityCost, abilityType)
	
	local regen = 0
	
	if(abilityType == POWERTYPE_STAMINA) then
		if is_player_in_combat then
			regen = GetPlayerStat(STAT_STAMINA_REGEN_COMBAT, STAT_BONUS_OPTION_APPLY_BONUS)
		else
			regen = GetPlayerStat(STAT_STAMINA_REGEN_IDLE, STAT_BONUS_OPTION_APPLY_BONUS)
		end
	elseif(abilityType == POWERTYPE_MAGICKA) then
		if is_player_in_combat then
			regen = GetPlayerStat(STAT_MAGICKA_REGEN_COMBAT, STAT_BONUS_OPTION_APPLY_BONUS)
		else
			regen = GetPlayerStat(STAT_MAGICKA_REGEN_IDLE, STAT_BONUS_OPTION_APPLY_BONUS)
		end
	else
		return
	end
	
	local current, maximum, e_maximum = GetUnitPower("player", abilityType)
	
	local time_to_reload = abilityCost / regen

	
	if(current < abilityCost) then
	
		if(regen ~= 0) then
			local result = time_to_reload - (current / regen)
			result = math.ceil(result)
		
			buttonControl_label:SetHidden(false)
			buttonControl_label:SetText(result)
		
		end
	else
	
		setLabelBlank(buttonControl_label)
	
	end
	
end

function setLabelBlank(label)

	label:SetText("")
	label:SetHidden(true)

end

local function RechargeCounterClassicUpdate(event)
	
	if not ZO_ActionBar1:IsHidden() then
		setLabels(1, button1, button1_label, GetSlotAbilityCost(3))
		setLabels(2, button2, button2_label, GetSlotAbilityCost(4))
		setLabels(3, button3, button3_label, GetSlotAbilityCost(5))
		setLabels(4, button4, button4_label, GetSlotAbilityCost(6))
		setLabels(5, button5, button5_label, GetSlotAbilityCost(7))
		db.showLabels = false
	else
		if(not db.showLabels) then
			setLabelBlank(button1_label)
			setLabelBlank(button2_label)
			setLabelBlank(button3_label)
			setLabelBlank(button4_label)
			setLabelBlank(button5_label)
		end
	end

end

local function createDB()
	RechargeCounterClassicSavedVars = RechargeCounterClassicSavedVars or {}
	for i,j in pairs(defaults) do
	    if type(RechargeCounterClassicSavedVars[i]) == "nil" then
	        RechargeCounterClassicSavedVars[i] = j
	    end
	end
	db = RechargeCounterClassicSavedVars
end


local function CombatStateChanged( eventCode, state )
	
	is_player_in_combat = state
	
end

function createSettings()
	local panelData = {
		type = panel,
		name = "Recharge Counter Classic",
		author = "Coreborn",
		version = "1.1",
		slashCommand = "/rcc",
	}
	
		local optionsData = {
		{
			type = "dropdown",
			name = "Font Type",
			tooltip = "The font to use for the labels",
			choices = {"ZoFontWindowTitle", "ZoFontBookTablet", "ZoFontBookPaperTitle", "ZoFontBookLetterTitle"},
			width = "full",
			getFunc = function() return db.font end,
			setFunc = function (value)
					db.font = value
					
					button1_label:SetFont(db.font)
					button2_label:SetFont(db.font)
					button3_label:SetFont(db.font)
					button4_label:SetFont(db.font)
					button5_label:SetFont(db.font)
					
				end,
		},
		{
			type = "slider",
			name = "Y-Axis Label Position",
			tooltip = "Set the Y-axis position of the labels",
			min = -50,
			max = 70,
			step = 1,
			width = "full",
			getFunc = function() return db.labelPositionY end,
			setFunc = function (value)
					db.labelPositionY = value
				
					button1_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button2_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button3_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button4_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button5_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					
				end,
		},
		{
			type = "slider",
			name = "X-Axis Label Position",
			tooltip = "Set the X-axis position of the labels",
			min = -50,
			max = 50,
			step = 1,
			width = "full",
			getFunc = function() return db.labelPositionX end,
			setFunc = function (value)
					db.labelPositionX = value
				
					button1_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button2_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button3_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button4_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					button5_label:SetAnchor(CENTER, abc, CENTER, db.labelPositionX, db.labelPositionY)
					
				end,
		},
		{
			type = "colorpicker",
			name = "Font Color",
			tooltip = "Select a color for the font",
			width = "full",
			getFunc = function() return db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a end,
			setFunc = function(r,g,b,a)
					db.fontColor.r = r
					db.fontColor.g = g
					db.fontColor.b = b
					db.fontColor.a = a
				
					button1_label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
					button2_label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
					button3_label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
					button4_label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
					button5_label:SetColor(db.fontColor.r, db.fontColor.g, db.fontColor.b, db.fontColor.a)
									
				end,
		},
		{
		    type = "checkbox",
            name = "Show position of labels",
            tooltip = "Show the label position for setup",
			width = "full",
            getFunc = function() return db.showLabels end,
            setFunc = function() 
					db.showLabels = not db.showLabels
			
					if db.showLabels then
						
						button1_label:SetHidden(false)
						button2_label:SetHidden(false)
						button3_label:SetHidden(false)
						button4_label:SetHidden(false)
						button5_label:SetHidden(false)
						
						button1_label:SetText("X")
						button2_label:SetText("X")
						button3_label:SetText("X")
						button4_label:SetText("X")
						button5_label:SetText("X")
						
					else
						
						setLabelBlank(button1_label)
						setLabelBlank(button2_label)
						setLabelBlank(button3_label)
						setLabelBlank(button4_label)
						setLabelBlank(button5_label)
	
					end
			end
        },
	}

	LAM:RegisterAddonPanel("Recharge Counter Classic", panelData)
	LAM:RegisterOptionControls("Recharge Counter Classic", optionsData)

end

local function InitEvents( eventCode, addonName )
	if(addonName == "RechargeCounterClassic") then
	
	createDB()
	createLabels()
	createSettings()
	
    RechargeCounterClassic:RegisterForEvent(EVENT_PLAYER_COMBAT_STATE, CombatStateChanged)
	EVENT_MANAGER:RegisterForUpdate("RechargeCounterClassic", 50, RechargeCounterClassicUpdate)
	
	end
end

function RCCLoad()

	EVENT_MANAGER:RegisterForEvent("RechargeCounterClassic", EVENT_ADD_ON_LOADED, InitEvents)

end